"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vscode_1 = require("vscode");
const os = require("os");
class FolderNode {
    constructor(name, children) {
        this.name = name;
        this.children = children;
    }
}
exports.FolderNode = FolderNode;
class ConnectionNode {
    constructor(name, host, port, schema, username, password) {
        this.name = name;
        this.host = host;
        this.port = port;
        this.schema = schema;
        this.username = username;
        this.password = password;
    }
}
exports.ConnectionNode = ConnectionNode;
class ConnectionModel {
    constructor(data) {
        this.data = data;
    }
    traverse(data) {
        return data['items'].map((x) => {
            if (x['type'] == 'connection') {
                return new ConnectionNode(x['name'], x['host'], x['port'], x['sid'], x['username'], x['password']);
            }
            else {
                return new FolderNode(x['name'], this.traverse(x));
            }
        });
    }
    get roots() {
        let list = this.traverse(this.data);
        return new Promise((c, e) => c(list));
    }
    getChildren(node) {
        if (node instanceof FolderNode) {
            return new Promise((c, e) => c(node.children));
        }
        else {
            return new Promise((c, e) => c([]));
        }
    }
}
exports.ConnectionModel = ConnectionModel;
class ConnectionProvider {
    constructor() {
        this._onDidChangeTreeData = new vscode_1.EventEmitter();
        this.onDidChangeTreeData = this._onDidChangeTreeData.event;
    }
    getTreeItem(element) {
        if (element instanceof FolderNode) {
            return {
                label: element.name,
                collapsibleState: vscode_1.TreeItemCollapsibleState.Collapsed,
                command: void 0
            };
        }
        else {
            return {
                label: element.name,
                collapsibleState: void 0,
                command: {
                    command: 'frog.selectConnection',
                    arguments: [element],
                    title: 'Open Connection'
                }
            };
        }
    }
    getChildren(element) {
        if (!element) {
            if (!this.model) {
                let data = require(os.homedir() + '/.frog.json');
                this.model = new ConnectionModel(data);
            }
            return this.model.roots;
        }
        if (element instanceof FolderNode) {
            return element.children;
        }
        else {
            return [];
        }
    }
    provideTextDocumentContent(uri, token) {
        return "nix";
    }
}
exports.ConnectionProvider = ConnectionProvider;
//# sourceMappingURL=connections.js.map